@@ -1,9 +1,5 @@
 package Slovo::Controller;
 use Mojo::Base 'Mojolicious::Controller', -signatures;
-use feature qw(lexical_subs unicode_strings);
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
-
 
 has not_found_id   => sub { $_[0]->stranici->not_found_id };
 has not_found_code => 404;
