@@ -7,9 +7,7 @@ sub index ($c) {
   state $menu = [qw(minion groups users domove stranici celini)];
   $c->stash->{menu} = [
     map {
-      $_ =~ m'groups|minion|domove' && !$c->groups->is_admin($c->user->{id})
-        ? ()
-        : $_
+      $_ =~ m'groups|minion|domove' && !$c->groups->is_admin($c->user->{id}) ? () : $_
     } @$menu
   ];
   return $c->render();
