@@ -1,9 +1,8 @@
 package Slovo::Model::Domove;
 use Mojo::Base 'Slovo::Model', -signatures;
-use feature qw(lexical_subs unicode_strings);
+
 use Mojo::Collection;
-## no critic qw(TestingAndDebugging::ProhibitNoWarnings)
-no warnings "experimental::lexical_subs";
+
 my $table = 'domove';
 has table => $table;
 has 'dbx';
