@@ -78,7 +78,7 @@ function get_страници ($url, $parent) {
                 $item = `<div>${$page_link}${$expander_link}</div>`;
             if($row.is_dir === 1) {
                 $expander_url = $url_no_qs + '?'
-                    + $.param({pid: $row.id, 'ѩꙁыкъ': $row.language});
+                    + $.param({pid: $row.id, 'lang': $row.language});
                 $expander_link = `<a id="id${$row.id}"
                     href="${$expander_url}" class="folder-expander mui--pull-right">☰</a>`;
                 $item = `<strong>${$page_link}${$expander_link}</strong>`;
